@@ -46,15 +46,16 @@ class MenuEditor:
 			self.applications.dom = xml.dom.minidom.parse(self.applications.path)
 		self.__remove_whilespace_nodes(self.applications.dom)
 
-		self.settings = Menu()
-		self.settings.tree = gmenu.lookup_tree('settings.menu', gmenu.FLAGS_SHOW_EMPTY|gmenu.FLAGS_INCLUDE_EXCLUDED|gmenu.FLAGS_INCLUDE_NODISPLAY)
-		self.settings.visible_tree = gmenu.lookup_tree('settings.menu')
-		self.settings.path = os.path.join(util.getUserMenuPath(), self.settings.tree.get_menu_file())
-		if not os.path.isfile(self.settings.path):
-			self.settings.dom = xml.dom.minidom.parseString(util.getUserMenuXml(self.settings.tree))
-		else:
-			self.settings.dom = xml.dom.minidom.parse(self.settings.path)
+		self.settings = Menu() 	 
+		self.settings.tree = gmenu.lookup_tree('settings.menu', gmenu.FLAGS_SHOW_EMPTY|gmenu.FLAGS_INCLUDE_EXCLUDED|gmenu.FLAGS_INCLUDE_NODISPLAY) 	 
+		self.settings.visible_tree = gmenu.lookup_tree('settings.menu') 	 
+		self.settings.path = os.path.join(util.getUserMenuPath(), self.settings.tree.get_menu_file()) 	 
+		if not os.path.isfile(self.settings.path): 	 
+			self.settings.dom = xml.dom.minidom.parseString(util.getUserMenuXml(self.settings.tree)) 	 
+		else: 	 
+			self.settings.dom = xml.dom.minidom.parse(self.settings.path) 	 
 		self.__remove_whilespace_nodes(self.settings.dom)
+
 		self.save(True)
 
 	def save(self, from_loading=False):
@@ -94,8 +95,8 @@ class MenuEditor:
 			else:
 				menu.dom = xml.dom.minidom.parse(menu.path)
 			self.__remove_whilespace_nodes(menu.dom)
-			#reset undo/redo, no way to recover from this
-			self.__undo, self.__redo = [], []
+		#reset undo/redo, no way to recover from this
+		self.__undo, self.__redo = [], []
 		self.save()
 
 	def revertTree(self, menu):
@@ -438,7 +439,7 @@ class MenuEditor:
 				return self.__findMenu(menu_id, self.settings.tree.root)
 		if menu_id == self.applications.tree.root.menu_id:
 			return self.applications.tree.root
-		if menu_id == self.settings.tree.root:
+		if menu_id == self.settings.tree.root.menu_id:
 			return self.settings.tree.root
 		for item in parent.get_contents():
 			if item.get_type() == gmenu.TYPE_DIRECTORY:
@@ -533,7 +534,7 @@ class MenuEditor:
 			file_id = item.get_desktop_file_id()
 			keyfile = util.DesktopParser(file_path)
 		elif item == None and name == None:
-			raise Exception(_('New menu items need a name'))
+			raise Exception('New menu items need a name')
 		else:
 			file_id = util.getUniqueFileId(name, '.desktop')
 			keyfile = util.DesktopParser()
@@ -566,7 +567,7 @@ class MenuEditor:
 			file_path = menu.get_desktop_file_path()
 			keyfile = util.DesktopParser(file_path)
 		elif menu == None and name == None:
-			raise Exception(_('New menus need a name'))
+			raise Exception('New menus need a name')
 		else:
 			file_id = util.getUniqueFileId(name, '.directory')
 			keyfile = util.DesktopParser(file_type='Directory')
